#!/usr/bin/env python
# coding:utf-8
"""
@author: nivic ybyang7
@license: Apache Licence
@file: aischema.py
@time: 2022/11/17
@contact: ybyang7@iflytek.com
@site:
@software: PyCharm

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
import copy
import json
from json import JSONEncoder
from collections.abc import Callable, Mapping
from flask_restx import Api, Resource, Namespace, Model, OrderedModel, fields, swagger
from flask import Flask
import jsonref
from enum import Enum
from pydantic import BaseModel, Field, create_model
from typing import Optional, Dict
from pydantic.fields import ModelField
import pprint
from aiges.schema.utils.schemaUtils import resolve_schema


class AIModel(BaseModel):
    class Config:
        allow_mutation = True
        extra = 'allow'

    def __init__(self, *args, **kwargs):
        super(AIModel, self).__init__(*args, **kwargs)

    @classmethod
    def add_key_datatype(cls, f_key, f_type):
        new_fields: Dict[str, ModelField] = {}
        new_annotations: Dict[str, Optional[type]] = {}
        f_annotation = None
        if f_annotation:
            new_annotations[f_key] = f_annotation

        f_value = {"dataType": f_type}
        new_fields[f_key] = ModelField.infer(name=f_key, value=f_value, annotation=f_annotation, class_validators=None,
                                             config=cls.__config__)

        cls.__fields__.update(new_fields)
        # cls.__annotations__.update(new_annotations)

    def add_key_media_type(cls, f_key, m: BaseModel):
        new_fields: Dict[str, ModelField] = {}
        new_annotations: Dict[str, Optional[type]] = {}
        f_annotation = None
        if f_annotation:
            new_annotations[f_key] = f_annotation
        # cls.__setattr__(name=f_key, value=m)
        new_fields[f_key] = ModelField.infer(name=f_key, value=m, annotation=f_annotation, class_validators=None,
                                             config=cls.__config__)

        cls.__fields__.update(new_fields)


class Input(AIModel):
    pass


class Accept(AIModel):
    pass


class Meta(BaseModel):
    '''
    {
        "serviceId": "s6d69bb68",
        "version": "v1.0",
        "service": [
            "s6d69bb68"
        ],
        "sub": "ase",
        "call": "atmos-low-concurrency",
        "call_type": "0",
        "webgate_type": 0,
        "hosts": "api.xf-yun.com",
        "route": "/v1/private/s6d69bb68",
        "s6d69bb68": {
            "input": {
                "input_text": {
                    "dataType": "text"
                }
            },
            "accept": {
                "output_imgs": {
                    "dataType": "image"
                }
            }
        },

    }'''

    serviceId: str = Field()
    version: str = Field()
    sub: str = Field()
    call: str = Field()
    call_type: str = Field()
    webgate_type: int = Field()
    hosts: str = Field()
    route: str = Field()


class Header(BaseModel):
    appid: str
    uid: Optional[str]
    device_id: Optional[str]
    imei: Optional[str]
    imsi: Optional[str]
    mac: Optional[str]
    net_type: Optional[str]
    net_isp: Optional[str]
    status: int
    res_id: Optional[str]


class SvcParameter(BaseModel):
    key1: str
    key2: str


class Parameter(AIModel):
    pass


class TextEncoding(str, Enum):
    utf8 = "utf8"
    gb2312 = "gb2312"
    gbk = "gbk"


class ImageEncoding(str, Enum):
    jpg = "jpg"
    png = "png"


class AudioEncoding(str, Enum):
    h264 = "h.264"


class Compress(str, Enum):
    raw = "raw"
    gzip = "gzip"


class TextFormat(str, Enum):
    xml = "xml"
    plain = "plain"
    json = "json"


class DataStatus(int, Enum):
    First = 0
    Continue = 1
    Last = 2
    Once = 3


class TextField(BaseModel):
    encoding: TextEncoding = Field(..., alias="encoding")
    compress: Compress = Field(..., alias="compress")
    format: TextFormat = Field(..., alias="format")
    status: DataStatus = Field(..., alias="status")
    text: str = Field(None, min_length=1, max_length=10485760)
    data_type: Optional[str] =Field("text")


class ImageField(BaseModel):
    encoding: ImageEncoding = Field(None, alias="encoding")
    status: DataStatus = Field(None, alias="status")
    image: str = Field(None, min_length=1, max_length=10485760)
    data_type: Optional[str] =Field("image")


class AudioField(BaseModel):
    encoding: AudioEncoding = Field(None, alias="encoding")
    status: DataStatus = Field(None, alias="status")
    audio: str = Field(None, min_length=1, max_length=10485760)
    data_type: Optional[str] =Field("audio")



class Payload(AIModel):
    pass


class SchemaInput(BaseModel):
    header: Header = Field(None, alias="header")
    parameter: Parameter = Field(None, alias="parameter")
    payload: Payload = Field(None, alias="payload")

    @classmethod
    def addPayloadData(cls, key_name: str, m: BaseModel):
        new_fields: Dict[str, ModelField] = {}
        new_annotations: Dict[str, Optional[type]] = {}
        f_annotation = None
        if f_annotation:
            new_annotations[key_name] = f_annotation
        f_value = {"dataType": 11}
        new_fields[key_name] = ModelField.infer(name=key_name, value=f_value, annotation=f_annotation,
                                                class_validators=None,
                                                config=cls.__config__)

        cls.__fields__.update(new_fields)


class SchemaOutput(BaseModel):
    def __int__(self):
        pass


class AIschema():
    def __init__(self, meta, schemainput, schemaoutput, is_aipaas=False, keep_default=True):
        self.meta = meta
        self.schemaoutput = schemaoutput
        self.schemainput = schemainput
        # 是否是aipaas协议， 兼容内部协议，控制兼容内部aipaas协议
        self.is_aipaas = is_aipaas
        # keep default 保留default
        self.keep_default = keep_default

    def json(self):
        meta = self.meta.dict()
        si = self.process_schema(self.schemainput.schema_json(), self.is_aipaas, self.keep_default)
        so = self.process_schema(self.schemaoutput.schema_json(), self.is_aipaas, self.keep_default)
        return dict(meta=meta, schemainput=si, schemaoutput=so)

    def aipaas(self):
        '''用于替换aipaas实现的 schema， 如default相关字段， 兼容协议'''
        pass

    def process_schema(self, schemajson, is_aipaas, keep_default):
        schema = jsonref.loads(schemajson)
        b = resolve_schema(schema, is_aipaas, keep_default)
        if "definitions" in b:
            del b['definitions']
        # if 'payload' in b['properties']:
        #     if 'allOf' in b['properties']['payload']:
        #         allof = copy.copy(b['properties']['payload']['allOf'][0])
        #         del b['properties']['payload']['allOf']
        #         b['properties']['payload']['properties'] = allof
        #
        #
        #     if 'default' in b['properties']['payload']:
        #         del b['properties']['payload']['default']

        return b


if __name__ == '__main__':
    MAX_TRIES = 100
    # schema = SchemaInput.schema()
    # for i in range(MAX_TRIES):
    #     if '$ref' not in json.dumps(schema):
    #         break
    #     schema = replace_value_in_dict(schema.copy(), schema.copy())
    #
    # del schema['definitions']
    s = SchemaInput.schema_json()
    dd = SchemaInput(header=Header(status=1, appid="c'c"))
    ss = json.loads(s)
    schema = jsonref.loads(s)

    # print(json.dumps(schema, indent=4))
    d = {"sid": "ccc"}
    MetaModel = create_model(
        'MetaModel',
        __base__=Meta,
        **d,
    )
    new_fields: Dict[str, ModelField] = {}

    fname = "scccid"

    Input.add_key_datatype("input_text", "text")
    Input.add_key_datatype("input_text2", "image")
    parameter = Input()

    Accept.add_key_datatype("result", "image")
    accept = Accept()
    v = {"accept": accept, "input": parameter}

    new_fields[fname] = ModelField.infer(name=fname, value=v, annotation=None, class_validators=None,
                                         config=MetaModel.__config__)
    MetaModel.__fields__.update(new_fields)

    a = MetaModel(serviceId="cc", sub="ccd", call="0", call_type="aipaas", webgate_type="c", hosts="ccdd", route="v1",
                  version="v4")
    # parameter.add_key_data_type("k1", "text")
    # pprint.pprint(a.json(), indent=4)
    p = Payload()
    pd = {"p111": TextField(encoding="utf8", format="plain", compress="raw", status=3, text="123"),
          "p22": TextField(encoding="utf8", format="plain", compress="raw", status=3, text="123")}

    PayloadModel = create_model(
        'PayloadModel',
        __base__=Payload,
        **pd
    )
    pdd = {"payload": PayloadModel(), "header": Header(appid="11", status="3"), "parameter": Parameter()}
    SchemaInputModel = create_model(
        'SchemaInputModel',
        **pdd,
        __base__=BaseModel
    )
    sin = SchemaInputModel()

    sc = AIschema(meta=a, schemainput=SchemaInputModel, schemaoutput=SchemaOutput())
    print(json.dumps(sc.json(), indent=4))

    t = TextField(text=b" ").schema_json()
    print(t)



#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: client
@time: 2022/10/29
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
from __future__ import print_function

import logging
import random

import grpc
from aiges.aiges_inner import aiges_inner_pb2
from aiges.aiges_inner import aiges_inner_pb2_grpc


def init(stub):
    ret = stub.wrapperInit(aiges_inner_pb2.InitRequest(config={"ccc": "ddd"}))
    print(ret.ret)


def generate_request():
    messages = [
        "1", "2", "3"
    ]
    for msg in messages:
        print("Sending %s" % (msg))
        yield aiges_inner_pb2.StreamRequest(data=msg)


def make_msg(value, key):
    return aiges_inner_pb2.Request(params={key: value}
                                   )


def generate_messages():
    messages = [
        make_msg("First message", "1" ),
        make_msg("Second message", "2"),
        make_msg("Third message", "3"),
        make_msg("Fourth message", "4"),
        make_msg("Fifth message", "5"),
    ]
    for msg in messages:
       # print("Sending %s at %s" % (msg.message, msg.location))
        yield msg


def testStream(stub):
    ret = stub.testStream(generate_request())
    for response in ret:
        print("Received message %s " %
              (str(response.list)))


def communicatie(stub):
    responses = stub.communicate(generate_messages())
    for response in responses:
        print(response.list)


def run():
    # NOTE(gRPC Python Team): .close() is possible on a channel and should be
    # used in circumstances in which the with statement does not fit the needs
    # of the code.
    with grpc.insecure_channel('localhost:50053') as channel:
        stub = aiges_inner_pb2_grpc.WrapperServiceStub(channel)
        print("-------------- InitConfig --------------")
        init(stub)
        print("------testStream------")
        testStream(stub)
        print("------test 双向Stream------")
        communicatie(stub)

if __name__ == '__main__':
    logging.basicConfig()
    run()



#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: log.py
@time: 2022/07/27
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
import logging
import os

fmt = '%(asctime)s - %(name)s:%(funcName)s:%(lineno)s - %(levelname)s:  %(message)s'
level = logging.DEBUG
ch = logging.StreamHandler()
formatter = logging.Formatter(fmt)
ch.setFormatter(formatter)
ch.setLevel(logging.INFO)
log = logging.getLogger()
log.setLevel(level)
log.addHandler(ch)

logpath = "/log/app"


def getLogger(fmt=fmt, level=level, name="root"):
    global log
    ch = logging.StreamHandler()
    formatter = logging.Formatter(fmt)
    ch.setFormatter(formatter)
    ch.setLevel(logging.INFO)
    log.setLevel(level)
    for handler in log.handlers:
        log.removeHandler(handler)
    log.addHandler(ch)
    return log


def getFileLogger(fmt=fmt, level=level, name="python_wrapper"):
    log = logging.getLogger(name)
    if not os.path.isdir(logpath) or not os.path.exists(logpath):
        os.makedirs(logpath)

    lfname = os.path.join(logpath, name + ".log")
    ch = logging.FileHandler(lfname)
    formatter = logging.Formatter(fmt)
    ch.setFormatter(formatter)
    ch.setLevel(level)
    for handler in log.handlers:
        log.removeHandler(handler)
    log.addHandler(ch)
    return log



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_stdio.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10grpc_stdio.proto\x12\x06plugin\x1a\x1bgoogle/protobuf/empty.proto\"u\n\tStdioData\x12*\n\x07\x63hannel\x18\x01 \x01(\x0e\x32\x19.plugin.StdioData.Channel\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\".\n\x07\x43hannel\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06STDOUT\x10\x01\x12\n\n\x06STDERR\x10\x02\x32G\n\tGRPCStdio\x12:\n\x0bStreamStdio\x12\x16.google.protobuf.Empty\x1a\x11.plugin.StdioData0\x01\x42\x08Z\x06pluginb\x06proto3')



_STDIODATA = DESCRIPTOR.message_types_by_name['StdioData']
_STDIODATA_CHANNEL = _STDIODATA.enum_types_by_name['Channel']
StdioData = _reflection.GeneratedProtocolMessageType('StdioData', (_message.Message,), {
  'DESCRIPTOR' : _STDIODATA,
  '__module__' : 'grpc_stdio_pb2'
  # @@protoc_insertion_point(class_scope:plugin.StdioData)
  })
_sym_db.RegisterMessage(StdioData)

_GRPCSTDIO = DESCRIPTOR.services_by_name['GRPCStdio']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\006plugin'
  _STDIODATA._serialized_start=57
  _STDIODATA._serialized_end=174
  _STDIODATA_CHANNEL._serialized_start=128
  _STDIODATA_CHANNEL._serialized_end=174
  _GRPCSTDIO._serialized_start=176
  _GRPCSTDIO._serialized_end=247
# @@protoc_insertion_point(module_scope)



import base64
import copy
import json

import requests
import jsonpath_rw

from aiges.client.utils import ne_utils
from aiges.utils.log import log
# from data import response_path_list
from urllib import parse

media_type_list = ["text", "audio", "image", "video"]


# 准备请求数据
def prepare_req_data(request_data):
    new_request_data = copy.deepcopy(request_data)
    media_path2name = {}
    for media_type in media_type_list:
        media_expr = jsonpath_rw.parse("$..payload.*.{}".format(media_type))
        media_match = media_expr.find(new_request_data)
        if len(media_match) > 0:
            for media in media_match:
                media_path2name[str(media.full_path)] = media.value
    for media_path, media_name in media_path2name.items():
        payload_path_list = media_path.split(".")
        f_data = ne_utils.get_file_bytes(media_name)
        new_request_data['header']['status'] = 3
        new_request_data['payload'][payload_path_list[1]][payload_path_list[2]] = base64.b64encode(f_data).decode()
        new_request_data['payload'][payload_path_list[1]]['status'] = 3
    return new_request_data


# 执行http请求
def execute(request_url, request_data, method, app_id, api_key, api_secret, callback=lambda x: x):
    # 清除文件
    ne_utils.del_file('./resource/output')

    # 获取请求url
    auth_request_url = ne_utils.build_auth_request_url(request_url, method, api_key, api_secret)

    url_result = parse.urlparse(request_url)
    headers = {'content-type': "application/json", 'host': url_result.hostname, 'app_id': app_id}
    # 准备待发送的数据
    new_request_data = prepare_req_data(request_data)
    log.debug("请求数据:{}\n".format(new_request_data))
    response = requests.post(auth_request_url, data=json.dumps(new_request_data), headers=headers)
    callback(response)



# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2017-2018 CERN.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Invenio JSONSchemas utils."""

from __future__ import absolute_import, print_function

from copy import deepcopy


def resolve_schema(schema, is_aipaas=False, keep_default=True):
    """Transform JSON schemas "allOf".
    This is the default schema resolver.
    This function was created because some javascript JSON Schema libraries
    don't support "allOf". We recommend to use this function only in this
    specific case.
    This function is transforming the JSON Schema by removing "allOf" keywords.
    It recursively merges the sub-schemas as dictionaries. The process is
    completely custom and works only for simple JSON Schemas which use basic
    types (object, string, number, ...). Optional structures like "schema
    dependencies" or "oneOf" keywords are not supported.
    :param dict schema: the schema to resolve.
    :returns: the resolved schema
    .. note::
        The schema should have the ``$ref`` already resolved before running
        this method.
    """

    def traverse(schema):
        if isinstance(schema, dict):
            if is_aipaas:
                if "default" in schema:
                    _aipaas_default(schema, keep_default)
                if "title" in schema:
                    _aipaas_remove_title(schema)
            if "allOf" in schema:
                for x in schema.pop("allOf"):
                    sub_schema = x
                    sub_schema.pop("title", None)
                    schema = _merge_dicts(schema, sub_schema)
                schema = traverse(schema)

            elif "properties" in schema:
                for x in schema.get("properties", []):
                    schema["properties"][x] = traverse(schema["properties"][x])
            elif "items" in schema:
                schema["items"] = traverse(schema["items"])
        return schema

    return traverse(schema)


def _aipaas_default(schema, modify=True):
    if modify:
        default = schema.pop("default")
        schema['defaultVal'] = default
    else:
        del schema['default']


def _aipaas_remove_title(schema):
    del schema['title']


def _merge_dicts(first, second):
    """Merge the 'second' multiple-dictionary into the 'first' one."""
    new = deepcopy(first)
    for k, v in second.items():
        if isinstance(v, dict) and v:
            ret = _merge_dicts(new.get(k, dict()), v)
            new[k] = ret
        else:
            new[k] = second[k]
    return new



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aiges.aiges_inner import aiges_inner_pb2 as aiges_dot_aiges__inner_dot_aiges__inner__pb2


class WrapperServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.wrapperInit = channel.unary_unary(
                '/aiges.WrapperService/wrapperInit',
                request_serializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.InitRequest.SerializeToString,
                response_deserializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Ret.FromString,
                )
        self.wrapperOnceExec = channel.unary_unary(
                '/aiges.WrapperService/wrapperOnceExec',
                request_serializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Request.SerializeToString,
                response_deserializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Response.FromString,
                )
        self.wrapperSchema = channel.unary_unary(
                '/aiges.WrapperService/wrapperSchema',
                request_serializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.SvcId.SerializeToString,
                response_deserializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Schema.FromString,
                )
        self.testStream = channel.stream_stream(
                '/aiges.WrapperService/testStream',
                request_serializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.StreamRequest.SerializeToString,
                response_deserializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Response.FromString,
                )
        self.communicate = channel.stream_stream(
                '/aiges.WrapperService/communicate',
                request_serializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Request.SerializeToString,
                response_deserializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Response.FromString,
                )


class WrapperServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def wrapperInit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def wrapperOnceExec(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def wrapperSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def testStream(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def communicate(self, request_iterator, context):
        """
        Accepts a stream of RouteNotes sent while a route is being traversed,
        while receiving other RouteNotes (e.g. from other users).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WrapperServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'wrapperInit': grpc.unary_unary_rpc_method_handler(
                    servicer.wrapperInit,
                    request_deserializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.InitRequest.FromString,
                    response_serializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Ret.SerializeToString,
            ),
            'wrapperOnceExec': grpc.unary_unary_rpc_method_handler(
                    servicer.wrapperOnceExec,
                    request_deserializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Request.FromString,
                    response_serializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Response.SerializeToString,
            ),
            'wrapperSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.wrapperSchema,
                    request_deserializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.SvcId.FromString,
                    response_serializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Schema.SerializeToString,
            ),
            'testStream': grpc.stream_stream_rpc_method_handler(
                    servicer.testStream,
                    request_deserializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.StreamRequest.FromString,
                    response_serializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Response.SerializeToString,
            ),
            'communicate': grpc.stream_stream_rpc_method_handler(
                    servicer.communicate,
                    request_deserializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Request.FromString,
                    response_serializer=aiges_dot_aiges__inner_dot_aiges__inner__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'aiges.WrapperService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WrapperService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def wrapperInit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aiges.WrapperService/wrapperInit',
            aiges_dot_aiges__inner_dot_aiges__inner__pb2.InitRequest.SerializeToString,
            aiges_dot_aiges__inner_dot_aiges__inner__pb2.Ret.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def wrapperOnceExec(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aiges.WrapperService/wrapperOnceExec',
            aiges_dot_aiges__inner_dot_aiges__inner__pb2.Request.SerializeToString,
            aiges_dot_aiges__inner_dot_aiges__inner__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def wrapperSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/aiges.WrapperService/wrapperSchema',
            aiges_dot_aiges__inner_dot_aiges__inner__pb2.SvcId.SerializeToString,
            aiges_dot_aiges__inner_dot_aiges__inner__pb2.Schema.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def testStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/aiges.WrapperService/testStream',
            aiges_dot_aiges__inner_dot_aiges__inner__pb2.StreamRequest.SerializeToString,
            aiges_dot_aiges__inner_dot_aiges__inner__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def communicate(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/aiges.WrapperService/communicate',
            aiges_dot_aiges__inner_dot_aiges__inner__pb2.Request.SerializeToString,
            aiges_dot_aiges__inner_dot_aiges__inner__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: server
@time: 2022/10/28
@contact: ybyang7@iflytek.com
@site:
@software: PyCharm

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
from concurrent import futures
import logging

import grpc

from aiges.aiges_inner import aiges_inner_pb2

from aiges.aiges_inner import aiges_inner_pb2_grpc


class WrapperServiceServicer(aiges_inner_pb2_grpc.WrapperServiceServicer):
    """Provides methods that implement functionality of route guide server."""

    def __init__(self):
        pass

    def wrapperInit(self, request, context):
        print(request)
        return aiges_inner_pb2.Ret(ret=1)

    def wrapperOnceExec(self, request, context):
        print(request)
        return aiges_inner_pb2.Response(list=[])
        pass

    def testStream(self, request_iterator, context):
        prev_notes = []
        for new_note in request_iterator:
            print (new_note.data)
            prev_notes.append(new_note)

def serve():
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
    aiges_inner_pb2_grpc.add_WrapperServiceServicer_to_server(
        WrapperServiceServicer(), server)
    server.add_insecure_port('[::]:50052')
    server.start()
    server.wait_for_termination()


if __name__ == '__main__':
    logging.basicConfig()
    serve()


#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: flask_restx_test
@time: 2022/11/22
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
def test_Flas():
    # app = Flask(__name__)
    # api = Api(app, version='1.0', title='Sample API',
    #           description='A sample API',
    #           )

    api = Namespace("AISchema")
    todo = api.model('Todo', {
        'id': fields.Integer(readonly=True, description='The task unique identifier'),
        'task': fields.String(required=True, description='The task details')
    })

    schemaInput1 = api.model('schemaInput', {
        'required': ['header', "parameters", "payload"],
        'properties': {
            'header': {
                'type': 'object'
            },
            'parameter': {
                'type': 'object'
            },
            'payload': {
                'type': 'object'
            }
        },
        'type': 'object'
    })
    schemaInput1 = api.model("schemaInput", {
        "header": fields.Nested(todo),
        "parameter": fields.Nested(todo),
        "payload": fields.Nested(todo)
    })
    print(dir(schemaInput1))
    print(schemaInput1._schema)
    print(todo._schema)


def replace_value_in_dict(item, original_schema):
    if isinstance(item, list):
        return [replace_value_in_dict(i, original_schema) for i in item]
    elif isinstance(item, dict):
        if list(item.keys()) == ['$ref']:
            definitions = item['$ref'][2:].split('/')
            res = original_schema.copy()
            for definition in definitions:
                res = res[definition]
            return res
        else:
            return {key: replace_value_in_dict(i, original_schema) for key, i in item.items()}
    else:
        return item


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['aiges',
 'aiges.aiges_inner',
 'aiges.backup',
 'aiges.client',
 'aiges.client.utils',
 'aiges.cmd',
 'aiges.core',
 'aiges.examples.once.mmocr',
 'aiges.examples.stream.mmocr',
 'aiges.examples.stream.mock',
 'aiges.schema',
 'aiges.schema.utils',
 'aiges.serve',
 'aiges.test_data',
 'aiges.utils']

package_data = \
{'': ['*'], 'aiges': ['tpls/*']}

install_requires = \
['flask_restx>=1.0.0',
 'grpcio-health-checking>=1.50.0',
 'grpcio-tools>=1.50.0',
 'grpcio>=1.50.0',
 'jinja2>=2.0',
 'jsonref>=1.0.0',
 'plumbum>=1.7.0',
 'protobuf>=4.21',
 'pydantic>=1.8']

setup_kwargs = {
    'name': 'aiges',
    'version': '0.6.5',
    'description': "A module for test aiges's python wrapper.py",
    'long_description': None,
    'author': 'maybaby',
    'author_email': 'ybyang7@iflytek.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6',
}


setup(**setup_kwargs)



import os
import sys
from typing import Any

from plumbum import cli, colors
from aiges.utils.log import log
from aiges.cmd.create import *  # 初始化项目目录
from aiges.cmd.package import *


class AigesCliManager(cli.Application):
    # 程序名称
    PROGNAME = "aiges sdk工具包" | colors.green
    VERSION = "1.0" | colors.blue
    DESCRIPTION = "kahn的CLI集合"
    USAGE = "aiges ai套件工具"

    def main(self):
        if not self.nested_command:  # will be ``None`` if no sub-command follows
            log.fatal("No subcommand given!")
            print()
            self.help()
            return 1
        elif len(self.nested_command[1]) < 2 and any(
                "create" in arg for arg in self.nested_command[1]
        ):
            log.error(
                "Subcommand  missing  required arguments! use 'create --help'"
            )
            return 1


@AigesCliManager.subcommand("create")  # type: ignore
class ManagerCreate(cli.Application):
    DESCRIPTION = "Aiges create project..."

    parent: AigesCliManager
    project_name: Any = cli.SwitchAttr(
        ["--name", "-n"],
        str,
        group="Create",
        help="初始化wrapper.py工程项目名称",
        default="wrapperDemo",
    )

    init_path: Any = cli.SwitchAttr(
        ["--path", "-p"],
        str,
        group="Create",
        help="初始化工程位置",
        default="./",
    )

    @cli.autoswitch(str, argname="模块名")
    def test(self, args):
        print("creating..%s" % str(args))

    def targeted(self):
        class Args:
            pass

        arg = Args()
        arg.name = self.project_name
        arg.path = self.init_path
        create_project(arg)

    def main(self):
        self.targeted()
        log.info("Done")


@AigesCliManager.subcommand("pack")  # type: ignore
class ManagerPack(cli.Application):
    DESCRIPTION = "Aiges pack wrapper directory..."

    parent: AigesCliManager
    location: Any = cli.SwitchAttr(
        ["--location", "-l"],
        str,
        group="Pack",
        help="工程目录路径",
        default="./",
    )

    output_path: Any = cli.SwitchAttr(
        ["--output", "-o"],
        str,
        group="Pack",
        help="输出压缩包路径",
        default="./",
    )

    @cli.autoswitch(str, argname="模块名")
    def test(self, args):
        print("creating..%s" % str(args))

    def targeted(self):
        class Args:
            pass

        arg = Args()
        arg.location = self.location
        arg.output = self.output_path
        pack(arg)

    def main(self):
        self.targeted()
        log.info("Done")


@AigesCliManager.subcommand("config")  # type: ignore
class ManagerConfig(cli.Application):
    DESCRIPTION = "Aiges Config Helper..."

    def main(self):
        # self.targeted()
        log.info("Done")


@ManagerConfig.subcommand("set")
class ConfigSet(ManagerConfig):
    parent: ManagerConfig

    def main(self, *args, **kwargs):
        log.info("setting config ...")
        print(args)
        print(kwargs)

@ManagerConfig.subcommand("get")
class ConfigGet(ManagerConfig):
    parent: ManagerConfig

    def main(self, *args, **kwargs):
        log.info("Getting config ...")
        print(args)

if __name__ == '__main__':
    AigesCliManager.run()



#!/usr/bin/env python
# coding:utf-8
"""
@author: nivic ybyang7
@license: Apache Licence
@file: server
@time: 2022/10/28
@contact: ybyang7@iflytek.com
@site:
@software: PyCharm

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛
"""

import datetime
import importlib
import logging
import sys
import time
#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
from concurrent import futures
from io import StringIO
from logging.handlers import QueueHandler, QueueListener
# from queue import Queue
from multiprocessing import Queue

import grpc
from aiges.aiges_inner import aiges_inner_pb2
from aiges.aiges_inner import aiges_inner_pb2_grpc
from aiges.aiges_inner import grpc_stdio_pb2
from aiges.aiges_inner import grpc_stdio_pb2_grpc
from aiges.dto import DataListCls
from aiges.errors import *
from aiges.utils.log import getLogger
from grpc_health.v1 import health_pb2, health_pb2_grpc
from grpc_health.v1.health import HealthServicer

log = getLogger(fmt=" %(name)s:%(funcName)s:%(lineno)s - %(levelname)s:  %(message)s", name="wrapper")
wrapper_module = "wrapper"
wrapper_class = "Wrapper"


class StdioService(grpc_stdio_pb2_grpc.GRPCStdioServicer):
    def __init__(self, log):
        self.log = log

    def StreamStdio(self, request, context):
        while True:
            sd = grpc_stdio_pb2.StdioData(channel=1, data=self.log.read())
            yield sd


class Logger:
    def __init__(self):
        self.stream = StringIO()  #
        que = Queue(-1)  # no limit on size
        self.queue_handler = QueueHandler(que)
        self.handler = logging.StreamHandler()
        self.listener = QueueListener(que, self.handler)
        self.log = logging.getLogger('python-plugin')
        self.log.setLevel(logging.INFO)
        self.logFormatter = logging.Formatter('%(asctime)s %(levelname)s  %(name)s %(pathname)s:%(lineno)d - %('
                                              'message)s')
        # self.handler.setFormatter(self.logFormatter)
        for handler in self.log.handlers:
            self.log.removeHandler(handler)
        self.log.addHandler(self.handler)
        self.listener.start()

    def __del__(self):
        pass
        # self.listener.stop()

    def read(self):
        self.handler.flush()
        ret = self.logFormatter.format(self.listener.queue.get()) + "\n"
        return ret.encode("utf-8")


class WrapperServiceServicer(aiges_inner_pb2_grpc.WrapperServiceServicer):
    """Provides methods that implement functionality of route guide server."""

    def __init__(self, q):
        self.response_queue = q
        self.count = 0
        self.userWrapperObject = None
        pass

    def wrapperInit(self, request, context):
        log.info("Importing module from wrapper.py: %s", wrapper_module)
        try:
            interface_file = importlib.import_module(wrapper_module)
            user_wrapper_cls = getattr(interface_file, wrapper_class)
            self.userWrapperObject = user_wrapper_cls(legacy=False, is_aipaas=True, keep_schema_default_value=True)
            log.info("User Wrapper newed Success.. starting call user init functions...")
            ret = self.userWrapperObject.wrapperInit(request.config)
            if ret != 0:
                log.error("User wrapperInit function failed.. ret: %s" % str(ret))
                return aiges_inner_pb2.Ret(ret=USER_INIT_ERROR)

        except Exception as e:
            log.error(e)
            ret = INIT_ERROR
            return aiges_inner_pb2.Ret(ret=ret)

        return aiges_inner_pb2.Ret(ret=OK)

    def wrapperOnceExec(self, request, context):
        if not self.userWrapperObject:
            return aiges_inner_pb2.Response(ret=USER_EXEC_ERROR)
        self.count += 1
        user_resp = self.userWrapperObject.wrapperOnceExec(request.params, self.convertPbReq2Req(request))
        if not user_resp or not user_resp.list:
            return aiges_inner_pb2.Response(ret=USER_EXEC_ERROR)
        d_list = []
        for ur in user_resp.list:
            d = aiges_inner_pb2.ResponseData(key=ur.key, data=ur.data, len=ur.len, status=ur.status)
            d_list.append(d)
        r = aiges_inner_pb2.Response(list=d_list, tag=request.tag)
        call_back(self.response_queue, r)
        return aiges_inner_pb2.Response(list=[])

    def wrapperSchema(self, request, context):
        log.info("Entering warpperSchema ...")
        if not self.userWrapperObject:
            return aiges_inner_pb2.Response(ret=USER_EXEC_ERROR)
        schame = self.userWrapperObject.schema()
        return aiges_inner_pb2.Schema(data=schame)

    def convertPbReq2Req(self, req):
        r = DataListCls()
        r.list = req.list
        return r

    def testStream(self, request_iterator, context):
        prev_notes = []
        for new_note in request_iterator:
            print(new_note.data)
            yield aiges_inner_pb2.Response(list=[])
            prev_notes.append(new_note)

    def communicate(self, request_iterator, context):
        # 这里无需双向似乎，如有必要，需要在加载器中传入相关信息
        while True:
            data = self.response_queue.get()
            yield data


def call_back(response_queue, r):
    response_queue.put(r)


def send_to_queue(q):
    x = 0
    while True:
        x += 1
        time.sleep(1)
        # print("sending... {}".format(x))
        msg = "count: {} . now : {}".format(x, datetime.datetime.now())
        d = aiges_inner_pb2.ResponseData(key=str(x), data=msg.encode("utf-8"), len=x, status=3)
        r = aiges_inner_pb2.Response(list=[d])
        # q.put(r)


def serve():
    work_q = Queue()
    # w = threading.Thread(target=send_to_queue, args=(work_q,))
    # w.start()

    # We need to build a health service to work with go-plugin
    health = HealthServicer()
    health.set("plugin", health_pb2.HealthCheckResponse.ServingStatus.Value('SERVING'))
    # Start the server.
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
    aiges_inner_pb2_grpc.add_WrapperServiceServicer_to_server(
        WrapperServiceServicer(work_q), server)
    # add stdio service
    # 这里没有必要，因为go-plugin似乎已经捕捉了 标准输出
    # grpc_stdio_pb2_grpc.add_GRPCStdioServicer_to_server(StdioService(logger), server)

    health_pb2_grpc.add_HealthServicer_to_server(health, server)

    server.add_insecure_port('[::]:50055')
    server.start()
    # Output information
    print("1|1|tcp|127.0.0.1:50055|grpc")
    sys.stdout.flush()

    server.wait_for_termination()


def run():
    logging.basicConfig()
    serve()


if __name__ == '__main__':
    run()
